import React from 'react';
import CodeMirror from '@uiw/react-codemirror';
import { SplitProps } from 'uiw/lib/esm/split';
import { ICodePenOption } from './CodePen';
import './monokai.css';
import './index.less';
export interface ICodePreviewProps extends SplitProps {
    prefixCls?: string;
    style?: React.CSSProperties;
    /**
     * To specify a CSS class, use the className attribute.
     */
    className?: string;
    /**
     * string|object. The mode to use. When not given, this will default to the first mode that was loaded.
     * It may be a string, which either simply names the mode or is a MIME type associated with the mode.
     * Alternatively, it may be an object containing configuration options for the mode,
     * with a name property that names the mode (for example `{name: "javascript", json: true}` ).
     */
    language?: string | {
        name: string;
        json: boolean;
    };
    /**
     * Whether to display the border.
     */
    bordered?: boolean;
    /**
     * `JSX` source code
     */
    code?: string;
    /**
     * Whether to display the code interface.
     */
    noCode?: boolean;
    /**
     * Is the background white or plaid?
     */
    bgWhite?: boolean;
    /**
     * Whether to display the preview interface.
     */
    noPreview?: boolean;
    /**
     * Preview area does not display scroll bars
     */
    noScroll?: boolean;
    /**
     * Dependent component
     */
    dependencies?: {
        [key: string]: any;
    };
    codePenOption?: ICodePenOption;
}
export interface ICodePreviewState {
    errorMessage: string;
    fullScreen: boolean;
    width: number | string;
    copied: boolean;
    showEdit: boolean;
}
export default class CodePreview extends React.PureComponent<ICodePreviewProps, ICodePreviewState> {
    demoDom: React.RefObject<HTMLDivElement>;
    editor: React.RefObject<CodeMirror>;
    initHeight: number;
    playerId: string;
    static defaultProps: ICodePreviewProps;
    state: ICodePreviewState;
    constructor(props: ICodePreviewProps);
    componentDidMount(): void;
    UNSAFE_componentWillReceiveProps(nextProps: ICodePreviewProps): void;
    executeCode(codeStr: string): Promise<void>;
    /**
     * onCopyCode
     */
    onCopyCode(): void;
    /**
     * onFullScreen
     */
    onFullScreen(): void;
    initOldHeight(): void;
    /**
     * onSwitchSource
     */
    onSwitchSource(): void;
    render(): JSX.Element;
}
